import * as React from 'react';
import { BoxProps } from '../Box';
import { ButtonProps } from '../Button';
import { DropdownMenuPopoverProps, DropdownMenuItemProps, DropdownMenuInitialState } from '../DropdownMenu';
import { InputProps } from '../Input';
import { TagProps } from '../Tag';
import { Size } from '../types';
declare type Option = {
    key: number | string;
    label: string;
    value: any;
};
declare type Options = Array<Option>;
export declare type LocalSelectMenuProps = {
    /** The key to cache the loadOptions results against. */
    cacheKey?: string;
    /** If the `label` prop is supplied, is it contained inside the select? */
    containLabel?: boolean;
    /** Whether or not the invocation of loadOptions should be deferred until it the Autosuggest is opened. */
    defer?: boolean;
    /** Indicates if the  Autosuggest is disabled. */
    disabled?: boolean;
    /** Indicates if the clear button should be disabled. */
    disableClear?: boolean;
    /** Indicates if the select menu has a search component. */
    hasSearch?: boolean;
    /** Indicates if the select menu should have tags of the selected options. */
    hasTags?: boolean;
    /** Indicates if the select menu is a dropdown menu. Default: `true` */
    isDropdown?: boolean;
    /** Indicates if the select menu is loading. */
    isLoading?: boolean;
    /** Indicates if multiple options should be selected. */
    isMultiSelect?: boolean;
    label?: string;
    /** Applies a limit to the number of options that appear in the list. */
    limit?: number;
    /** Supply an async function to `loadOptions` to load options from an external data source. */
    loadOptions?: (options: {
        page?: number;
        searchText?: string;
        variables?: any;
    }) => Promise<{
        options: Options;
    }>;
    /** Supply variables (i.e. query parameters) to the `loadOptions` function. */
    loadVariables?: {
        [key: string]: any;
    };
    /** Options to show in the list. If `loadOptions` is supplied, then you don't need to supply this. */
    options?: Options;
    /** Function to invoke when the option has been changed. */
    onChange: (newOptions: Array<Option> | Option | '', option: Option | '') => void;
    /** Indicates if the list should be paginated. If `true`, then pagination will be applied to `loadOptions`. */
    pagination?: boolean;
    /** Sets the height of the popover list. */
    popoverHeight?: string;
    /** Sets the placeholder of the search input. */
    placeholder?: string;
    /** Sets the size of the select menu button */
    size?: Size;
    /** Sets the visual state of the Autosuggest. */
    state?: string;
    /** Sets the value of the Autosuggest. Must be in the shape of an option (i.e. `{ key: 1, label: 'Jake', value: 'legend' }`). */
    value: Partial<Option>;
    errorText?: string;
    emptyText?: string;
    loadingText?: string;
    loadingMoreText?: string;
    renderBottomActions?: any;
    renderDisclosure?: any;
    renderError?: any;
    renderEmpty?: any;
    renderLoading?: any;
    renderLoadingMore?: any;
    renderOption?: any;
    renderTopActions?: any;
    buttonProps?: Partial<ButtonProps>;
    itemProps?: Partial<DropdownMenuItemProps>;
    popoverProps?: Partial<DropdownMenuPopoverProps>;
    searchInputProps?: Partial<InputProps>;
    tagProps?: Partial<TagProps>;
    dropdownMenuInitialState?: Partial<DropdownMenuInitialState>;
};
export declare type SelectMenuProps = BoxProps & LocalSelectMenuProps;
export declare type SelectMenuContextOptions = {
    dropdownMenu?: any;
    overrides?: any;
    themeKey?: string;
};
export declare const SelectMenuContext: React.Context<SelectMenuContextOptions>;
export declare const SelectMenu: React.ForwardRefExoticComponent<Pick<SelectMenuProps, "bottom" | "left" | "right" | "top" | "pointerEvents" | "all" | "fill" | "stroke" | "label" | "slot" | "style" | "title" | "clipPath" | "filter" | "marker" | "mask" | "use" | "children" | "backgroundColor" | "colorMode" | "value" | "key" | "hidden" | "variant" | "themeKey" | "altitude" | "animation" | "appearance" | "azimuth" | "background" | "border" | "caret" | "chains" | "clear" | "clip" | "color" | "columns" | "contain" | "content" | "continue" | "cue" | "cursor" | "direction" | "display" | "elevation" | "flex" | "float" | "flow" | "font" | "gap" | "grid" | "height" | "hyphens" | "inset" | "isolation" | "margin" | "marginX" | "marginY" | "offset" | "opacity" | "order" | "orphans" | "outline" | "overflow" | "padding" | "paddingX" | "paddingY" | "page" | "pause" | "perspective" | "pitch" | "position" | "quotes" | "resize" | "rest" | "richness" | "rotation" | "running" | "speak" | "stress" | "transform" | "transition" | "visibility" | "volume" | "widows" | "width" | "className" | "id" | "lang" | "role" | "tabIndex" | "alignmentBaseline" | "baselineShift" | "clipRule" | "colorInterpolationFilters" | "dominantBaseline" | "fillOpacity" | "fillRule" | "floodColor" | "floodOpacity" | "fontFamily" | "fontSize" | "fontSizeAdjust" | "fontStretch" | "fontStyle" | "fontVariant" | "fontWeight" | "glyphOrientationVertical" | "letterSpacing" | "lightingColor" | "markerEnd" | "markerMid" | "markerStart" | "strokeDasharray" | "strokeDashoffset" | "strokeLinecap" | "strokeLinejoin" | "strokeMiterlimit" | "strokeOpacity" | "strokeWidth" | "textDecoration" | "unicodeBidi" | "wordSpacing" | "writingMode" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "placeholder" | "spellCheck" | "translate" | "radioGroup" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "disabled" | "size" | "defer" | "alignContent" | "alignItems" | "alignSelf" | "animationDelay" | "animationDirection" | "animationDuration" | "animationFillMode" | "animationIterationCount" | "animationName" | "animationPlayState" | "animationTimingFunction" | "backfaceVisibility" | "backgroundAttachment" | "backgroundBlendMode" | "backgroundClip" | "backgroundImage" | "backgroundOrigin" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "blockSize" | "borderBlockColor" | "borderBlockEndColor" | "borderBlockEndStyle" | "borderBlockEndWidth" | "borderBlockStartColor" | "borderBlockStartStyle" | "borderBlockStartWidth" | "borderBlockStyle" | "borderBlockWidth" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomStyle" | "borderBottomWidth" | "borderCollapse" | "borderImageOutset" | "borderImageRepeat" | "borderImageSlice" | "borderImageSource" | "borderImageWidth" | "borderInlineColor" | "borderInlineEndColor" | "borderInlineEndStyle" | "borderInlineEndWidth" | "borderInlineStartColor" | "borderInlineStartStyle" | "borderInlineStartWidth" | "borderInlineStyle" | "borderInlineWidth" | "borderLeftColor" | "borderLeftStyle" | "borderLeftWidth" | "borderRightColor" | "borderRightStyle" | "borderRightWidth" | "borderSpacing" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopStyle" | "borderTopWidth" | "boxDecorationBreak" | "boxShadow" | "boxSizing" | "breakAfter" | "breakBefore" | "breakInside" | "captionSide" | "caretColor" | "colorAdjust" | "columnCount" | "columnFill" | "columnGap" | "columnRuleColor" | "columnRuleStyle" | "columnRuleWidth" | "columnSpan" | "columnWidth" | "counterIncrement" | "counterReset" | "counterSet" | "emptyCells" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "fontFeatureSettings" | "fontKerning" | "fontLanguageOverride" | "fontOpticalSizing" | "fontSynthesis" | "fontVariantCaps" | "fontVariantEastAsian" | "fontVariantLigatures" | "fontVariantNumeric" | "fontVariantPosition" | "fontVariationSettings" | "gridAutoColumns" | "gridAutoFlow" | "gridAutoRows" | "gridColumnEnd" | "gridColumnStart" | "gridRowEnd" | "gridRowStart" | "gridTemplateAreas" | "gridTemplateColumns" | "gridTemplateRows" | "hangingPunctuation" | "imageOrientation" | "imageResolution" | "initialLetter" | "inlineSize" | "insetBlock" | "insetBlockEnd" | "insetBlockStart" | "insetInline" | "insetInlineEnd" | "insetInlineStart" | "justifyContent" | "justifyItems" | "justifySelf" | "lineBreak" | "lineHeight" | "lineHeightStep" | "listStyleImage" | "listStylePosition" | "listStyleType" | "marginBlock" | "marginBlockEnd" | "marginBlockStart" | "marginBottom" | "marginInline" | "marginInlineEnd" | "marginInlineStart" | "marginLeft" | "marginRight" | "marginTop" | "maskBorderMode" | "maskBorderOutset" | "maskBorderRepeat" | "maskBorderSlice" | "maskBorderSource" | "maskBorderWidth" | "maskClip" | "maskComposite" | "maskImage" | "maskMode" | "maskOrigin" | "maskPosition" | "maskRepeat" | "maskSize" | "maskType" | "maxBlockSize" | "maxHeight" | "maxInlineSize" | "maxLines" | "maxWidth" | "minBlockSize" | "minHeight" | "minInlineSize" | "minWidth" | "mixBlendMode" | "objectFit" | "objectPosition" | "offsetAnchor" | "offsetDistance" | "offsetPath" | "offsetRotate" | "outlineColor" | "outlineOffset" | "outlineStyle" | "outlineWidth" | "overflowWrap" | "overflowX" | "overflowY" | "paddingBlock" | "paddingBlockEnd" | "paddingBlockStart" | "paddingBottom" | "paddingInline" | "paddingInlineEnd" | "paddingInlineStart" | "paddingLeft" | "paddingRight" | "paddingTop" | "pageBreakAfter" | "pageBreakBefore" | "pageBreakInside" | "perspectiveOrigin" | "placeContent" | "rowGap" | "rubyAlign" | "rubyMerge" | "rubyPosition" | "scrollBehavior" | "scrollPadding" | "scrollPaddingBlock" | "scrollPaddingBlockEnd" | "scrollPaddingBlockStart" | "scrollPaddingBottom" | "scrollPaddingInline" | "scrollPaddingInlineEnd" | "scrollPaddingInlineStart" | "scrollPaddingLeft" | "scrollPaddingRight" | "scrollPaddingTop" | "scrollSnapAlign" | "scrollSnapMargin" | "scrollSnapMarginBottom" | "scrollSnapMarginLeft" | "scrollSnapMarginRight" | "scrollSnapMarginTop" | "scrollSnapStop" | "scrollSnapType" | "scrollbarGutter" | "shapeImageThreshold" | "shapeMargin" | "shapeOutside" | "tabSize" | "tableLayout" | "textAlign" | "textAlignLast" | "textCombineUpright" | "textDecorationColor" | "textDecorationLine" | "textDecorationSkip" | "textDecorationStyle" | "textEmphasisColor" | "textEmphasisPosition" | "textEmphasisStyle" | "textIndent" | "textJustify" | "textOrientation" | "textOverflow" | "textShadow" | "textTransform" | "textUnderlinePosition" | "transformBox" | "transformOrigin" | "transformStyle" | "transitionDelay" | "transitionDuration" | "transitionProperty" | "transitionTimingFunction" | "userSelect" | "verticalAlign" | "whiteSpace" | "willChange" | "wordBreak" | "wordWrap" | "zIndex" | "borderBlock" | "borderBlockEnd" | "borderBlockStart" | "borderBottom" | "borderColor" | "borderImage" | "borderInline" | "borderInlineEnd" | "borderInlineStart" | "borderLeft" | "borderRadius" | "borderRight" | "borderStyle" | "borderTop" | "borderWidth" | "columnRule" | "flexFlow" | "gridArea" | "gridColumn" | "gridRow" | "gridTemplate" | "listStyle" | "maskBorder" | "placeItems" | "placeSelf" | "textEmphasis" | "fontVariantAlternates" | "gridColumnGap" | "gridGap" | "gridRowGap" | "gradientDirection" | "gradientFrom" | "gradientFromAt" | "gradientTo" | "gradientToAt" | "gradientVia" | "gradientViaAt" | "alignX" | "alignY" | "borderLeftRadius" | "borderRightRadius" | "unstable_system" | "wrapElement" | "_hover" | "_hoveractive" | "_focus" | "_active" | "_visited" | "_disabled" | "_groupHover" | "_groupActive" | "_groupFocus" | "_groupVisited" | "_groupDisabled" | "backgroundImageTransform" | "blockStep" | "blockStepAlign" | "blockStepInsert" | "blockStepRound" | "blockStepSize" | "bookmarkLabel" | "bookmarkLevel" | "bookmarkState" | "borderBoundary" | "borderImageTransform" | "boxSnap" | "caretAnimation" | "caretShape" | "cueAfter" | "cueBefore" | "fillBreak" | "fillColor" | "fillImage" | "fillOrigin" | "fillPosition" | "fillRepeat" | "fillSize" | "floatDefer" | "floatOffset" | "floatReference" | "flowFrom" | "flowInto" | "fontMaxSize" | "fontMinSize" | "fontPalette" | "fontPresentation" | "footnoteDisplay" | "footnotePolicy" | "hyphenateCharacter" | "hyphenateLimitChars" | "hyphenateLimitLast" | "hyphenateLimitLines" | "hyphenateLimitZone" | "initialLetterAlign" | "initialLetterWrap" | "lineGrid" | "lineSnap" | "markerKnockoutLeft" | "markerKnockoutRight" | "markerPattern" | "markerSegment" | "markerSide" | "marqueeDirection" | "marqueeLoop" | "marqueeSpeed" | "marqueeStyle" | "navDown" | "navLeft" | "navRight" | "navUp" | "offsetAfter" | "offsetBefore" | "offsetEnd" | "offsetPosition" | "offsetStart" | "overflowStyle" | "pauseAfter" | "pauseBefore" | "pitchRange" | "playDuring" | "presentationLevel" | "regionFragment" | "restAfter" | "restBefore" | "rotationPoint" | "scrollSnapMarginBlock" | "scrollSnapMarginBlockEnd" | "scrollSnapMarginBlockStart" | "scrollSnapMarginInline" | "scrollSnapMarginInlineEnd" | "scrollSnapMarginInlineStart" | "shapeInside" | "speakAs" | "speakHeader" | "speakNumeral" | "speakPunctuation" | "speechRate" | "stringSet" | "strokeAlign" | "strokeAlignment" | "strokeBreak" | "strokeColor" | "strokeDashCorner" | "strokeDashJustify" | "strokeDashadjust" | "strokeDashcorner" | "strokeImage" | "strokeOrigin" | "strokePosition" | "strokeRepeat" | "strokeSize" | "textAlignAll" | "textSpaceCollapse" | "textSpaceTrim" | "textSpacing" | "textWrap" | "voiceBalance" | "voiceDuration" | "voiceFamily" | "voicePitch" | "voiceRange" | "voiceRate" | "voiceStress" | "voiceVolume" | "wrapAfter" | "wrapBefore" | "wrapFlow" | "wrapInside" | "wrapThrough" | "overrides" | "elementRef" | "state" | "isLoading" | "containLabel" | "cacheKey" | "limit" | "loadOptions" | "loadVariables" | "options" | "pagination" | "popoverHeight" | "errorText" | "emptyText" | "loadingText" | "loadingMoreText" | "renderError" | "renderEmpty" | "renderLoading" | "renderLoadingMore" | "renderOption" | "itemProps" | "popoverProps" | "dropdownMenuInitialState" | "buttonProps" | "isDropdown" | "disableClear" | "hasSearch" | "hasTags" | "isMultiSelect" | "renderBottomActions" | "renderDisclosure" | "renderTopActions" | "searchInputProps" | "tagProps"> & React.RefAttributes<unknown>> & {
    displayName?: string;
    useProps: (props?: Partial<SelectMenuProps>, config?: {
        disableCSSProps?: string[];
        themeKey?: string;
    }) => any;
};
export {};
